/**
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2007-2012 Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.plugin.migration.artifactory;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.zip.ZipEntry;
import java.util.zip.ZipException;
import java.util.zip.ZipFile;

import org.restlet.data.Status;
import org.restlet.resource.ResourceException;
import org.sonatype.nexus.plugin.migration.artifactory.util.XStreamUtil;
import org.sonatype.nexus.rest.AbstractNexusPlexusResource;

import com.thoughtworks.xstream.XStream;

public abstract class AbstractArtifactoryMigrationPlexusResource
    extends AbstractNexusPlexusResource
{
    public AbstractArtifactoryMigrationPlexusResource()
    {
        super();
    }

    @Override
    public void configureXStream( XStream xstream )
    {
        super.configureXStream( xstream );

        XStreamUtil.configureMigration(xstream);
    }

    protected File validateBackupFileLocation( String fileLocation )
        throws ResourceException
    {
        File file = new File( fileLocation );

        if ( !file.exists() )
        {
            throw new ResourceException( Status.CLIENT_ERROR_BAD_REQUEST, "Invalid File Location: "
                + file.getAbsolutePath() );
        }

        if ( file.isFile() )
        {
            ZipFile zip;
            try
            {
                zip = new ZipFile( file );
                zip.close();
            }
            catch ( ZipException e )
            {
                throw new ResourceException( Status.CLIENT_ERROR_BAD_REQUEST, "Invalid file format. Is not a Zip. "
                    + e.getMessage() );
            }
            catch ( IOException e )
            {
                throw new ResourceException( Status.CLIENT_ERROR_BAD_REQUEST, "Unable to read file. " + e.getMessage() );
            }
        }

        return file;
    }

    protected InputStream getConfigurationFile( File backup, String filename )
        throws IOException, ZipException, FileNotFoundException, ResourceException
    {
        ZipFile zipFile = null;

        if ( backup.isFile() )
        {
            zipFile = new ZipFile( backup );
        }

        final InputStream cfg;
        if ( zipFile != null )
        {
            ZipEntry cfgEntry = zipFile.getEntry( filename );
            if ( cfgEntry == null )
            {
                cfg = null;
            }
            else
            {
                cfg = zipFile.getInputStream( cfgEntry );
            }
        }
        else
        {
            File cfgFile = new File( backup, filename );
            if ( !cfgFile.exists() )
            {
                cfg = null;
            }
            else
            {
                cfg = new FileInputStream( cfgFile );
            }
        }

        if ( cfg == null )
        {
            throw new ResourceException( Status.CLIENT_ERROR_BAD_REQUEST, "Artifactory backup is invalid, missing: '"
                + filename + "'" );
        }
        return cfg;

    }

}
