/**
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2007-2012 Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.plugin.migration.artifactory.config;

import static org.sonatype.nexus.plugin.migration.artifactory.util.DomUtil.getValue;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.codehaus.plexus.util.xml.Xpp3Dom;

public class ArtifactoryVirtualRepository
{
    private Xpp3Dom dom;

    private List<String> resolvedRepositories;

    private List<String> repositories;

    public ArtifactoryVirtualRepository( Xpp3Dom dom )
    {
        this.dom = dom;
    }

    public String getKey()
    {
        return getValue( dom, "key" );
    }

    public List<String> getRepositories()
    {
        if ( repositories == null )
        {
            Xpp3Dom repositoriesDom = dom.getChild( "repositories" );
            if ( repositoriesDom == null )
            {
                repositories = Collections.emptyList();
            }
            else
            {
                repositories = new ArrayList<String>();
                for ( Xpp3Dom repoDom : repositoriesDom.getChildren( "repositoryRef" ) )
                {
                    repositories.add( repoDom.getValue() );
                }
                repositories = Collections.unmodifiableList( repositories );
            }
        }
        return repositories;
    }

    public List<String> getResolvedRepositories()
    {
        return resolvedRepositories;
    }

    public void setResolvedRepositories( List<String> resolvedRepositories )
    {
        this.resolvedRepositories = resolvedRepositories;
    }

}
