/**
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2007-2012 Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.plugin.migration.artifactory.dto;

import java.util.ArrayList;
import java.util.List;

import com.thoughtworks.xstream.annotations.XStreamAlias;

@XStreamAlias( "migrationSummaryDTO" )
public class MigrationSummaryDTO
{
    private String id;

    private String backupLocation;

    private List<UserResolutionDTO> usersResolution;

    private boolean resolvePermission;

    private List<RepositoryResolutionDTO> repositoriesResolution;

    private List<GroupResolutionDTO> groupsResolution;

    private String nexusContext;

    public MigrationSummaryDTO()
    {
        super();
    }

    public List<RepositoryResolutionDTO> getRepositoriesResolution()
    {
        if ( repositoriesResolution == null )
        {
            repositoriesResolution = new ArrayList<RepositoryResolutionDTO>();
        }
        return repositoriesResolution;
    }

    public void setRepositoriesResolution( List<RepositoryResolutionDTO> repositoriesResolution )
    {
        this.repositoriesResolution = repositoriesResolution;
    }

    public String getBackupLocation()
    {
        return backupLocation;
    }

    public void setBackupLocation( String backupLocation )
    {
        this.backupLocation = backupLocation;
    }

    public List<UserResolutionDTO> getUsersResolution()
    {
        if ( usersResolution == null )
        {
            usersResolution = new ArrayList<UserResolutionDTO>();
        }
        return usersResolution;
    }

    public void setUsersResolution( List<UserResolutionDTO> userResolution )
    {
        this.usersResolution = userResolution;
    }

    public boolean isResolvePermission()
    {
        return resolvePermission;
    }

    public void setResolvePermission( boolean resolvePermission )
    {
        this.resolvePermission = resolvePermission;
    }

    public void setGroupsResolution( List<GroupResolutionDTO> groupsResolution )
    {
        this.groupsResolution = groupsResolution;
    }

    public List<GroupResolutionDTO> getGroupsResolution()
    {
        if ( groupsResolution == null )
        {
            groupsResolution = new ArrayList<GroupResolutionDTO>();
        }
        return groupsResolution;
    }

    public RepositoryResolutionDTO getRepositoryResolution( String repoId )
    {
        if ( repoId == null )
        {
            return null;
        }

        for ( RepositoryResolutionDTO resolution : getRepositoriesResolution() )
        {
            if ( repoId.equals( resolution.getRepositoryId() ) )
            {
                return resolution;
            }
        }
        return null;
    }

    public GroupResolutionDTO getGroupResolution( String groupId )
    {
        if ( groupId == null )
        {
            return null;
        }

        for ( GroupResolutionDTO resolution : getGroupsResolution() )
        {
            if ( groupId.equals( resolution.getGroupId() ) )
            {
                return resolution;
            }
        }
        return null;
    }

    public String getId()
    {
        return id;
    }

    public void setId( String id )
    {
        this.id = id;
    }

    public String getNexusContext()
    {
        return nexusContext;
    }

    public void setNexusContext( String nexusContext )
    {
        this.nexusContext = nexusContext;
    }

}
