/**
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2007-2012 Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.plugin.migration.artifactory.security;

import java.util.ArrayList;
import java.util.List;

public class ArtifactoryPermissionTarget
{
    private static int defaultIdCount = 1001;

    private String id;

    private List<String> repoKeys = new ArrayList<String>();

    private List<String> includes = new ArrayList<String>();

    private List<String> excludes = new ArrayList<String>();

    public ArtifactoryPermissionTarget()
    {
        this.id = "arti-perm-target-" + defaultIdCount;

        defaultIdCount++;
    }

    public ArtifactoryPermissionTarget( String id )
    {
        this.id = id;
    }

    public ArtifactoryPermissionTarget( String id, String repoKey )
    {
        this.id = id;

        this.repoKeys.add( repoKey );
    }

    public List<String> getRepoKeys()
    {
        return repoKeys;
    }

    public void setRepoKeys( List<String> repoKeys )
    {
        this.repoKeys = repoKeys;
    }

    public void addRepoKey( String repoKey )
    {
        if ( !this.repoKeys.contains( repoKey ) )
        {
            repoKeys.add( repoKey );
        }
    }

    public String getId()
    {
        return id;
    }

    public List<String> getIncludes()
    {
        return includes;
    }

    public List<String> getExcludes()
    {
        return excludes;
    }

    public void addInclude( String include )
    {
        includes.add( include );
    }

    public void addExclude( String exclude )
    {
        excludes.add( exclude );
    }

    @Override
    public boolean equals( Object obj )
    {
        if ( this == obj )
        {
            return true;
        }

        if ( !( obj instanceof ArtifactoryPermissionTarget ) )
        {
            return false;
        }

        ArtifactoryPermissionTarget repoTarget = (ArtifactoryPermissionTarget) obj;

        return id.equals( repoTarget.id ) && repoKeys.equals( repoTarget.repoKeys )
            && includes.equals( repoTarget.includes ) && excludes.equals( repoTarget.excludes );
    }

}
