/**
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2007-2012 Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.plugin.migration.artifactory.security.builder;

import org.codehaus.plexus.util.xml.Xpp3Dom;
import org.sonatype.nexus.plugin.migration.artifactory.security.ArtifactorySecurityConfig;

public abstract class AbstractSecurityConfigParser
{
    private Xpp3Dom dom;

    private ArtifactorySecurityConfig config;

    public AbstractSecurityConfigParser( Xpp3Dom dom, ArtifactorySecurityConfig config )
    {
        this.dom = dom;

        this.config = config;
    }

    protected Xpp3Dom getDom()
    {
        return dom;
    }

    protected ArtifactorySecurityConfig getConfig()
    {
        return config;
    }

    abstract protected void parseUsers();

    abstract protected void parseGroups();
    
    abstract protected void parsePermissionTargets();

    abstract protected void parseAcls();
    
    public void parse()
    {
        // NOTE that this order is critical
        parseGroups();
        
        parseUsers();
        
        parsePermissionTargets();
        
        parseAcls();
    }
}
