/**
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2007-2012 Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.plugin.migration.artifactory.security.builder;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;

import org.codehaus.plexus.util.IOUtil;
import org.codehaus.plexus.util.ReaderFactory;
import org.codehaus.plexus.util.xml.XmlStreamReader;
import org.codehaus.plexus.util.xml.Xpp3Dom;
import org.codehaus.plexus.util.xml.Xpp3DomBuilder;
import org.codehaus.plexus.util.xml.pull.XmlPullParserException;
import org.sonatype.nexus.plugin.migration.artifactory.security.ArtifactorySecurityConfig;

public class ArtifactorySecurityConfigBuilder
{
    public static final String VERSION_125 = "1.2.5";

    public static final String VERSION_130 = "1.3.0";

    public static final String VERSION_UNKNOWN = "unknown";

    public static ArtifactorySecurityConfig read( File file )
        throws IOException,
            XmlPullParserException
    {
        XmlStreamReader reader = ReaderFactory.newXmlReader( file );

        try
        {
            return build( Xpp3DomBuilder.build( reader ) );
        }

        finally
        {
            IOUtil.close( reader );
        }
    }

    public static ArtifactorySecurityConfig read( InputStream inputStream )
        throws IOException,
            XmlPullParserException
    {
        XmlStreamReader reader = ReaderFactory.newXmlReader( inputStream );

        try
        {
            return build( Xpp3DomBuilder.build( reader ) );
        }
        finally
        {
            IOUtil.close( reader );
        }
    }

    /**
     * @param dom
     * @return version of the security config dom
     */
    public static String validate( Xpp3Dom dom )
    {
        if ( dom.getChild( "users" ) == null )
        {
            return VERSION_UNKNOWN;
        }

        if ( dom.getChild( "users" ).getChildren( "org.artifactory.security.SimpleUser" ).length > 0 )
        {
            return VERSION_125;
        }

        if ( dom.getChild( "users" ).getChildren( "user" ).length > 0 )
        {
            return VERSION_130;
        }

        return VERSION_UNKNOWN;
    }

    public static ArtifactorySecurityConfig build( Xpp3Dom dom )
    {
        ArtifactorySecurityConfig securityConfig = new ArtifactorySecurityConfig();

        if ( validate( dom ).equals( VERSION_125 ) )
        {
            new SecurityConfig125Parser( dom, securityConfig ).parse();
        }
        else if ( validate( dom ).equals( VERSION_130 ) )
        {
            new SecurityConfig130Parser( dom, securityConfig ).parse();
        }

        return securityConfig;

    }

}
